'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');

function ChevronDownSvg(props) {
    return (jsxRuntime.jsx("svg", Object.assign({}, props, { width: '16', height: '16', viewBox: '0 0 16 16', fill: 'none', xmlns: 'http://www.w3.org/2000/svg' }, { children: jsxRuntime.jsx("path", { d: 'M4 6L8 10L12 6', stroke: 'currentColor', strokeWidth: '1', strokeLinecap: 'round', strokeLinejoin: 'round' }) })));
}

function Copy({ text }) {
    const [copied, setCopied] = react.useState(false);
    const copy = (e) => {
        e.stopPropagation();
        navigator.clipboard.writeText(text);
        setCopied(true);
        setTimeout(() => setCopied(false), 3000);
    };
    return copied ? (jsxRuntime.jsxs("svg", Object.assign({ className: 'json-view--copy', style: { display: 'inline-block' }, xmlns: 'http://www.w3.org/2000/svg', width: '24', height: '24', viewBox: '0 0 24 24' }, { children: [jsxRuntime.jsx("path", { stroke: '#A1E3CB', d: 'm10.933 13.519-2.226-2.226-1.414 1.414 3.774 3.774 5.702-6.84-1.538-1.282z' }), jsxRuntime.jsx("path", { d: 'M19 3H5c-1.103 0-2 .897-2 2v14c0 1.103.897 2 2 2h14c1.103 0 2-.897 2-2V5c0-1.103-.897-2-2-2zM5 19V5h14l.002 14H5z' })] }))) : (jsxRuntime.jsx("svg", Object.assign({ onClick: copy, className: 'json-view--copy', xmlns: 'http://www.w3.org/2000/svg', width: '24', height: '24', viewBox: '0 0 24 24' }, { children: jsxRuntime.jsx("path", { d: 'M20 2H10c-1.103 0-2 .897-2 2v4H4c-1.103 0-2 .897-2 2v10c0 1.103.897 2 2 2h10c1.103 0 2-.897 2-2v-4h4c1.103 0 2-.897 2-2V4c0-1.103-.897-2-2-2zM4 20V10h10l.002 10H4zm16-6h-4v-4c0-1.103-.897-2-2-2h-4V4h10v10z' }) })));
}

const JsonViewContext = react.createContext({
    collapseStringsAfterLength: 99,
    collapseObjectsAfterLength: 20,
    enableClipboard: true
});
function JsonView({ src, collapseStringsAfterLength = 99, collapseObjectsAfterLength = 20, enableClipboard = true }) {
    return (jsxRuntime.jsx(JsonViewContext.Provider, Object.assign({ value: { collapseStringsAfterLength, collapseObjectsAfterLength, enableClipboard } }, { children: jsxRuntime.jsx("code", Object.assign({ className: 'json-view' }, { children: jsxRuntime.jsx(JsonNode, { node: src }) })) })));
}
function JsonNode({ node }) {
    const jv = react.useContext(JsonViewContext);
    if (Array.isArray(node) || isObject(node)) {
        return jsxRuntime.jsx(ObjectNode, { node: node });
    }
    else if (typeof node === 'number')
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", Object.assign({ className: 'json-view--number' }, { children: node })), jv.enableClipboard && jsxRuntime.jsx(Copy, { text: String(node) })] }));
    else if (typeof node === 'string')
        return node.length > jv.collapseStringsAfterLength ? (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(LongString, { str: node }), jv.enableClipboard && jsxRuntime.jsx(Copy, { text: String(node) })] })) : (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsxs("span", Object.assign({ className: 'json-view--string' }, { children: ["\"", node, "\""] })), jv.enableClipboard && jsxRuntime.jsx(Copy, { text: String(node) })] }));
    else if (typeof node === 'boolean')
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", Object.assign({ className: 'json-view--boolean' }, { children: String(node) })), jv.enableClipboard && jsxRuntime.jsx(Copy, { text: String(node) })] }));
    else if (node === null)
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", Object.assign({ className: 'json-view--null' }, { children: "null" })), jv.enableClipboard && jsxRuntime.jsx(Copy, { text: String(node) })] }));
    else
        return jsxRuntime.jsx("span", Object.assign({ className: 'json-view--string' }, { children: String(node) }));
}
function ObjectNode({ node }) {
    const jv = react.useContext(JsonViewContext);
    const [fold, setFold] = react.useState(Array.isArray(node) && node.length > jv.collapseObjectsAfterLength
        ? true
        : isObject(node) && Object.keys(node).length > jv.collapseObjectsAfterLength
            ? true
            : false);
    if (Array.isArray(node)) {
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", { children: '[' }), !fold && jsxRuntime.jsx(ChevronDownSvg, { onClick: () => setFold(true), className: 'jv-chevron' }), !fold && jv.enableClipboard && jsxRuntime.jsx(Copy, { text: JSON.stringify(node) }), !fold ? (jsxRuntime.jsx("div", Object.assign({ className: 'jv-indent' }, { children: node.map((n, i) => (jsxRuntime.jsx(NameValue, { name: i, value: n }, i))) }))) : (jsxRuntime.jsx("button", Object.assign({ onClick: () => setFold(false), className: 'jv-button' }, { children: "..." }))), jsxRuntime.jsx("span", { children: ']' })] }));
    }
    else if (isObject(node)) {
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", { children: '{' }), !fold && jsxRuntime.jsx(ChevronDownSvg, { onClick: () => setFold(true), className: 'jv-chevron' }), !fold && jv.enableClipboard && jsxRuntime.jsx(Copy, { text: JSON.stringify(node) }), !fold ? (jsxRuntime.jsx("div", Object.assign({ className: 'jv-indent' }, { children: Object.entries(node).map(([name, value]) => (jsxRuntime.jsx(NameValue, { name: name, value: value }, name))) }))) : (jsxRuntime.jsx("button", Object.assign({ onClick: () => setFold(false), className: 'jv-button' }, { children: "..." }))), jsxRuntime.jsx("span", { children: '}' })] }));
    }
    return null;
}
function LongString({ str }) {
    if (str.length <= 10)
        return jsxRuntime.jsxs("span", Object.assign({ className: 'json-view--string' }, { children: ["\"", str, "\""] }));
    const [fold, setFold] = react.useState(true);
    return (jsxRuntime.jsxs("span", Object.assign({ onClick: () => setFold(!fold), className: 'json-view--string cursor-pointer' }, { children: ["\"", fold ? str.slice(0, 6) + '...' + str.slice(-4) : str, "\""] })));
}
function NameValue({ name, value }) {
    return (jsxRuntime.jsxs("div", Object.assign({ className: 'json-view--pair' }, { children: [jsxRuntime.jsx("span", Object.assign({ className: typeof name === 'number' ? 'json-view--index' : 'json-view--property' }, { children: name })), ":", ' ', jsxRuntime.jsx(JsonNode, { node: value })] })));
}
function isObject(node) {
    return Object.prototype.toString.call(node) === '[object Object]';
}

module.exports = JsonView;
//# sourceMappingURL=index.cjs.map
